pub enum BlockType {
Raw,
Rle,
Compressed,
}Expand description
Valid Standard Frame block types supported by the structural parser.
Variants
Raw
Raw block whose encoded content length is Block_Size.
Rle
Run-length encoded block with exactly one encoded content byte.
Compressed
Compressed block whose payload is treated as opaque encoded bytes.